( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins/0.3.0.0__0738eb9f132ed756/Mono.Addins.dll Mono.Addins.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.Gui.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.Gui/0.3.0.0__0738eb9f132ed756/Mono.Addins.Gui.dll Mono.Addins.Gui.dll )
( cd usr/lib/mono/mono-addins ; rm -rf Mono.Addins.Setup.dll )
( cd usr/lib/mono/mono-addins ; ln -sf ../gac/Mono.Addins.Setup/0.3.0.0__0738eb9f132ed756/Mono.Addins.Setup.dll Mono.Addins.Setup.dll )
